<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       setectecnologia.com
 * @since      1.0.0
 *
 * @package    Setec_Donaciones_Aea
 * @subpackage Setec_Donaciones_Aea/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Setec_Donaciones_Aea
 * @subpackage Setec_Donaciones_Aea/admin
 * @author     Jefferson Quintero <quinterpriest@gmail.com>
 */
if (!class_exists('sfCsvWriter'))
{
	require_once dirname(__FILE__) . '/../libraries/csv/sfCsvWriter.class.php';   
}
class Setec_Donaciones_Aea_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Setec_Donaciones_Aea_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Setec_Donaciones_Aea_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/setec-donaciones-aea-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Setec_Donaciones_Aea_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Setec_Donaciones_Aea_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/setec-donaciones-aea-admin.js', array( 'jquery' ), $this->version, true );

	}

	public function add_menu_page() {

		$this->plugin_screen_hook_suffix = add_submenu_page(
			'edit.php?post_type=aea_donantes',
			'Planes',
			'Planes',
			'manage_options',
			'edit.php?post_type=aea_planes',
			NULL
		);
		$this->plugin_screen_hook_suffix = add_submenu_page(
			'edit.php?post_type=aea_donantes',
			'Tarjetas',
			'Tarjetas',
			'manage_options',
			'edit.php?post_type=aea_tarjetas',
			NULL
		);
		$this->plugin_screen_hook_suffix = add_submenu_page(
			'edit.php?post_type=aea_donantes',
			'Suscripciones',
			'Suscripciones',
			'manage_options',
			'edit.php?post_type=aea_suscripciones',
			NULL
		);


		$this->plugin_screen_hook_suffix = add_submenu_page(
			'edit.php?post_type=aea_donantes',
			'Exportar Donantes',
			'Exportar Donantes',
			'exportar_listado_donantes',
			'setec_exportar_donantes',
			array( $this, 'display_info_exportar_donantes_page' )
		);
		$this->plugin_screen_hook_suffix = add_submenu_page(
			'edit.php?post_type=aea_donantes',
			'Configuración',
			'Configuración',
			'manage_options',
			'donaciones_aea_configuracion',
			array( $this, 'display_options_page' )
		);
	}

	public function display_options_page() {
		include_once 'partials/setec-donaciones-aea-admin-display.php';
	}

	public function display_info_exportar_donantes_page() {
		include_once 'partials/setec-donaciones-aea-exportar-donantes-admin-display.php';
	}

	public function registrar_parametros_configuracion() 
	{
		add_settings_section(
			'setec_donaciones_aea_general',
			__( 'General', 'setec-donaciones-aea' ),
			array( $this, 'setec_donaciones_aea_general' ),
			$this->plugin_name
		);
		add_settings_field(
			'setec_donaciones_aea_payu_apikey',
			__( 'Apikey', 'setec-donaciones-aea' ),
			array( $this, 'setec_donaciones_aea_payu_apikey' ),
			$this->plugin_name,
			'setec_donaciones_aea_general',
			array( 'label_for' => 'setec_donaciones_aea_payu_apikey' )
		);
		add_settings_field(
			'setec_donaciones_aea_payu_apilogin',
			__( 'ApiLogin', 'setec-donaciones-aea' ),
			array( $this, 'setec_donaciones_aea_payu_apilogin' ),
			$this->plugin_name,
			'setec_donaciones_aea_general',
			array( 'label_for' => 'setec_donaciones_aea_payu_apilogin' )
		);
		add_settings_field(
			'setec_donaciones_aea_payu_merchantid',
			__( 'MerchantId', 'setec-donaciones-aea' ),
			array( $this, 'setec_donaciones_aea_payu_merchantid' ),
			$this->plugin_name,
			'setec_donaciones_aea_general',
			array( 'label_for' => 'setec_donaciones_aea_payu_merchantid' )
		);
		add_settings_field(
			'setec_donaciones_aea_payu_accountid',
			__( 'AccountId', 'setec-donaciones-aea' ),
			array( $this, 'setec_donaciones_aea_payu_accountid' ),
			$this->plugin_name,
			'setec_donaciones_aea_general',
			array( 'label_for' => 'setec_donaciones_aea_payu_accountid' )
		);
		register_setting( $this->plugin_name, 'setec_donaciones_aea_payu_apikey');
		register_setting( $this->plugin_name, 'setec_donaciones_aea_payu_apilogin');
		register_setting( $this->plugin_name, 'setec_donaciones_aea_payu_merchantid');
		register_setting( $this->plugin_name, 'setec_donaciones_aea_payu_accountid');
		//register_setting( $this->plugin_name, $this->option_name . 'setec_donaciones_aea_clave_api', array( $this, $this->option_name . 'setec_donaciones_aea_sanitize_position' ) );
		//register_setting( $this->plugin_name, $this->option_name . 'setec_donaciones_aea_usuario_api', 'intval' );
	}

	public function setec_donaciones_aea_general() {
		echo '<p>' . __( 'Por favor cambie estos parametros, en base a los dados por payulatam', 'setec-donaciones-aea' ) . '</p>
			<ul>
				<li>
					<b>Apikey</b>: apikey payulatam
				</li>
				<li>
					<b>ApiLogin</b>: apilogin payulatam
				</li>
				<li></li>
				<li><b>merchantid</b>: Codigo comercio payulatam</li>
			</ul>
		';
	}
	/**
	 * Render the radio input field for position option
	 *
	 * @since  1.0.0
	 */
	public function setec_donaciones_aea_payu_apikey() {
		$url_api = get_option( 'setec_donaciones_aea_payu_apikey' );
		echo '<input style="width:100%" type="text" name="setec_donaciones_aea_payu_apikey" id="setec_donaciones_aea_payu_apikey" value="' . $url_api . '"> ';
		
	}

	public function setec_donaciones_aea_payu_apilogin() {
		$url_api_login = get_option( 'setec_donaciones_aea_payu_apilogin' );
		echo '<input style="width:100%" type="text" name="setec_donaciones_aea_payu_apilogin" id="setec_donaciones_aea_payu_apilogin" value="' . $url_api_login . '"> ';
		
	}

	/**
	 * Render the treshold day input for this plugin
	 *
	 * @since  1.0.0
	 */
	public function setec_donaciones_aea_payu_merchantid() {
		$usuario_api = get_option( 'setec_donaciones_aea_payu_merchantid' );
		echo '<input style="width:100%" type="text" name="setec_donaciones_aea_payu_merchantid" id="setec_donaciones_aea_payu_merchantid" value="' . $usuario_api . '"> ';
	}

	public function setec_donaciones_aea_payu_accountid() {
		$usuario_api = get_option( 'setec_donaciones_aea_payu_accountid' );
		echo '<input style="width:100%" type="text" name="setec_donaciones_aea_payu_accountid" id="setec_donaciones_aea_payu_accountid" value="' . $usuario_api . '"> ';
	}

	public function custom_post_donantes()
    {
    	$capabilities=array(
			'publish_posts' => 'publish_listados_donaciones',
    		'edit_posts' => 'edit_listados_donaciones',
    		'edit_others_posts' => 'edit_others_listados_donaciones',
    		'delete_posts' => 'delete_listados_donaciones',
    		'delete_others_posts' => 'delete_others_listados_donaciones',
			'read_private_posts' => 'read_private_listados_donaciones',
    		'edit_post' => 'edit_listado_donaciones',
    		'delete_post' => 'delete_listado_donaciones',
    		'read_post' => 'read_listado_donaciones'
    	);
		
			$labels = array(
			'name'                  => _x( 'Donantes', 'Post Type General Name', 'setec-donaciones-aea' ),
			'singular_name'         => _x( 'Donantes', 'Post Type Singular Name', 'setec-donaciones-aea' ),
			'menu_name'             => __( 'Donantes', 'setec-donaciones-aea' ),
			'name_admin_bar'        => __( 'Donantes', 'setec-donaciones-aea' ),
			'archives'              => __( 'Archivos de Donantes', 'setec-donaciones-aea' ),
			'parent_item_colon'     => __( 'Elemento Padre:', 'setec-donaciones-aea' ),
			'all_items'             => __( 'Todos los Donantes', 'setec-donaciones-aea' ),
			'add_new_item'          => __( 'Añadir Nuevo Donante', 'setec-donaciones-aea' ),
			'add_new'               => __( 'Añadir Nuevo', 'setec-donaciones-aea' ),
			'new_item'              => __( 'Nuevo Donante', 'setec-donaciones-aea' ),
			'edit_item'             => __( 'Editar Donante', 'setec-donaciones-aea' ),
			'update_item'           => __( 'Actualizar Donante', 'setec-donaciones-aea' ),
			'view_item'             => __( 'Ver Donante', 'setec-donaciones-aea' ),
			'search_items'          => __( 'Buscar Donante', 'setec-donaciones-aea' ),
			'not_found'             => __( 'No encontrado', 'setec-donaciones-aea' ),
			'not_found_in_trash'    => __( 'No encontrado en la Papelera', 'setec-donaciones-aea' ),
			'featured_image'        => __( 'Imagen Destacada', 'setec-donaciones-aea' ),
			'set_featured_image'    => __( 'Elegir Imagen Destacada', 'setec-donaciones-aea' ),
			'remove_featured_image' => __( 'Quitar Imagen Destacada', 'setec-donaciones-aea' ),
			'use_featured_image'    => __( 'Usar como Imagen Destacada', 'setec-donaciones-aea' ),
			'insert_into_item'      => __( 'Insertar este elemento', 'setec-donaciones-aea' ),
			'uploaded_to_this_item' => __( 'Cargado a este elemento', 'setec-donaciones-aea' ),
			'items_list'            => __( 'Lista de Donantes', 'setec-donaciones-aea' ),
			'items_list_navigation' => __( 'Lista de Donantes', 'setec-donaciones-aea' ),
			'filter_items_list'     => __( 'Filtrar', 'setec-donaciones-aea' ),
		);
		$args = array(
			'label'                 => __( 'Listado Donantes', 'setec-donaciones-aea' ),
			'description'           => __( 'Registra los Donantes', 'setec-donaciones-aea' ),
			'labels'                => $labels,
			'supports'              => array( 'title' ),
			'taxonomies'            => array(),
			'hierarchical'          => false,
			'public'                => true,
			'show_ui'               => true,
			'show_in_menu'          => true,
			'menu_position'         => 100,
			'menu_icon'             => 'dashicons-calendar-alt',
			'show_in_admin_bar'     => true,
			'show_in_nav_menus'     => true,
			'can_export'            => true,
			'has_archive'           => true,		
			'exclude_from_search'   => true,
			'publicly_queryable'    => true,
			'capabilities'       => $capabilities,
		);
		register_post_type( 'aea_donantes', $args );

    }

    public function custom_post_planes()
    {
    	$capabilities=array(
			'publish_posts' => 'publish_listados_donaciones',
    		'edit_posts' => 'edit_listados_donaciones',
    		'edit_others_posts' => 'edit_others_listados_donaciones',
    		'delete_posts' => 'delete_listados_donaciones',
    		'delete_others_posts' => 'delete_others_listados_donaciones',
			'read_private_posts' => 'read_private_listados_donaciones',
    		'edit_post' => 'edit_listado_donaciones',
    		'delete_post' => 'delete_listado_donaciones',
    		'read_post' => 'read_listado_donaciones'
    	);
		
			$labels = array(
			'name'                  => _x( 'Planes', 'Post Type General Name', 'setec-donaciones-aea' ),
			'singular_name'         => _x( 'Planes', 'Post Type Singular Name', 'setec-donaciones-aea' ),
			'menu_name'             => __( 'Planes', 'setec-donaciones-aea' ),
			'name_admin_bar'        => __( 'Planes', 'setec-donaciones-aea' ),
			'archives'              => __( 'Archivos de Planes', 'setec-donaciones-aea' ),
			'parent_item_colon'     => __( 'Elemento Padre:', 'setec-donaciones-aea' ),
			'all_items'             => __( 'Todas los Planes', 'setec-donaciones-aea' ),
			'add_new_item'          => __( 'Añadir Nuevo Plan', 'setec-donaciones-aea' ),
			'add_new'               => __( 'Añadir Nuevo', 'setec-donaciones-aea' ),
			'new_item'              => __( 'Nuevo Plan', 'setec-donaciones-aea' ),
			'edit_item'             => __( 'Editar Plan', 'setec-donaciones-aea' ),
			'update_item'           => __( 'Actualizar Plan', 'setec-donaciones-aea' ),
			'view_item'             => __( 'Ver Plan', 'setec-donaciones-aea' ),
			'search_items'          => __( 'Buscar Plan', 'setec-donaciones-aea' ),
			'not_found'             => __( 'No encontrado', 'setec-donaciones-aea' ),
			'not_found_in_trash'    => __( 'No encontrado en la Papelera', 'setec-donaciones-aea' ),
			'featured_image'        => __( 'Imagen Destacada', 'setec-donaciones-aea' ),
			'set_featured_image'    => __( 'Elegir Imagen Destacada', 'setec-donaciones-aea' ),
			'remove_featured_image' => __( 'Quitar Imagen Destacada', 'setec-donaciones-aea' ),
			'use_featured_image'    => __( 'Usar como Imagen Destacada', 'setec-donaciones-aea' ),
			'insert_into_item'      => __( 'Insertar este elemento', 'setec-donaciones-aea' ),
			'uploaded_to_this_item' => __( 'Cargado a este elemento', 'setec-donaciones-aea' ),
			'items_list'            => __( 'Lista de Planes', 'setec-donaciones-aea' ),
			'items_list_navigation' => __( 'Lista de Planes', 'setec-donaciones-aea' ),
			'filter_items_list'     => __( 'Filtrar', 'setec-donaciones-aea' ),
		);
		$args = array(
			'label'                 => __( 'Listado planes', 'setec-donaciones-aea' ),
			'description'           => __( 'Registra los planes', 'setec-donaciones-aea' ),
			'labels'                => $labels,
			'supports'              => array( 'title' ),
			'taxonomies'            => array(),
			'hierarchical'          => false,
			'public'                => true,
			'show_ui'               => true,
			'show_in_menu'          => false,
			'menu_position'         => 100,
			'menu_icon'             => 'dashicons-calendar-alt',
			'show_in_admin_bar'     => false,
			'show_in_nav_menus'     => true,
			'can_export'            => true,
			'has_archive'           => true,		
			'exclude_from_search'   => true,
			'publicly_queryable'    => true,
			'capabilities'       => $capabilities,
		);
		register_post_type( 'aea_planes', $args );

    }

    public function custom_post_tarjetas()
    {
    	$capabilities=array(
			'publish_posts' => 'publish_listados_donaciones',
    		'edit_posts' => 'edit_listados_donaciones',
    		'edit_others_posts' => 'edit_others_listados_donaciones',
    		'delete_posts' => 'delete_listados_donaciones',
    		'delete_others_posts' => 'delete_others_listados_donaciones',
			'read_private_posts' => 'read_private_listados_donaciones',
    		'edit_post' => 'edit_listado_donaciones',
    		'delete_post' => 'delete_listado_donaciones',
    		'read_post' => 'read_listado_donaciones'
    	);
		
			$labels = array(
			'name'                  => _x( 'Tarjetas', 'Post Type General Name', 'setec-donaciones-aea' ),
			'singular_name'         => _x( 'Tarjetas', 'Post Type Singular Name', 'setec-donaciones-aea' ),
			'menu_name'             => __( 'Tarjetas', 'setec-donaciones-aea' ),
			'name_admin_bar'        => __( 'Tarjetas', 'setec-donaciones-aea' ),
			'archives'              => __( 'Archivos de Tarjetas', 'setec-donaciones-aea' ),
			'parent_item_colon'     => __( 'Elemento Padre:', 'setec-donaciones-aea' ),
			'all_items'             => __( 'Todas los Tarjetas', 'setec-donaciones-aea' ),
			'add_new_item'          => __( 'Añadir Nueva Tarjeta', 'setec-donaciones-aea' ),
			'add_new'               => __( 'Añadir Nueva', 'setec-donaciones-aea' ),
			'new_item'              => __( 'Nueva Tarjeta', 'setec-donaciones-aea' ),
			'edit_item'             => __( 'Editar Tarjeta', 'setec-donaciones-aea' ),
			'update_item'           => __( 'Actualizar Tarjeta', 'setec-donaciones-aea' ),
			'view_item'             => __( 'Ver Tarjeta', 'setec-donaciones-aea' ),
			'search_items'          => __( 'Buscar Tarjeta', 'setec-donaciones-aea' ),
			'not_found'             => __( 'No encontrada', 'setec-donaciones-aea' ),
			'not_found_in_trash'    => __( 'No encontrado en la Papelera', 'setec-donaciones-aea' ),
			'featured_image'        => __( 'Imagen Destacada', 'setec-donaciones-aea' ),
			'set_featured_image'    => __( 'Elegir Imagen Destacada', 'setec-donaciones-aea' ),
			'remove_featured_image' => __( 'Quitar Imagen Destacada', 'setec-donaciones-aea' ),
			'use_featured_image'    => __( 'Usar como Imagen Destacada', 'setec-donaciones-aea' ),
			'insert_into_item'      => __( 'Insertar este elemento', 'setec-donaciones-aea' ),
			'uploaded_to_this_item' => __( 'Cargado a este elemento', 'setec-donaciones-aea' ),
			'items_list'            => __( 'Lista de Tarjetas', 'setec-donaciones-aea' ),
			'items_list_navigation' => __( 'Lista de Tarjetas', 'setec-donaciones-aea' ),
			'filter_items_list'     => __( 'Filtrar', 'setec-donaciones-aea' ),
		);
		$args = array(
			'label'                 => __( 'Listado tarjetas', 'setec-donaciones-aea' ),
			'description'           => __( 'Registra las tarjetas', 'setec-donaciones-aea' ),
			'labels'                => $labels,
			'supports'              => array( 'title' ),
			'taxonomies'            => array(),
			'hierarchical'          => false,
			'public'                => true,
			'show_ui'               => true,
			'show_in_menu'          => false,
			'menu_position'         => 100,
			'menu_icon'             => 'dashicons-calendar-alt',
			'show_in_admin_bar'     => false,
			'show_in_nav_menus'     => true,
			'can_export'            => true,
			'has_archive'           => true,		
			'exclude_from_search'   => true,
			'publicly_queryable'    => true,
			'capabilities'       => $capabilities,
		);
		register_post_type( 'aea_tarjetas', $args );

    }

    public function custom_post_suscripciones()
    {
    	$capabilities=array(
			'publish_posts' => 'publish_listados_donaciones',
    		'edit_posts' => 'edit_listados_donaciones',
    		'edit_others_posts' => 'edit_others_listados_donaciones',
    		'delete_posts' => 'delete_listados_donaciones',
    		'delete_others_posts' => 'delete_others_listados_donaciones',
			'read_private_posts' => 'read_private_listados_donaciones',
    		'edit_post' => 'edit_listado_donaciones',
    		'delete_post' => 'delete_listado_donaciones',
    		'read_post' => 'read_listado_donaciones'
    	);
		
			$labels = array(
			'name'                  => _x( 'Suscripciones', 'Post Type General Name', 'setec-donaciones-aea' ),
			'singular_name'         => _x( 'Suscripciones', 'Post Type Singular Name', 'setec-donaciones-aea' ),
			'menu_name'             => __( 'Suscripciones', 'setec-donaciones-aea' ),
			'name_admin_bar'        => __( 'Suscripciones', 'setec-donaciones-aea' ),
			'archives'              => __( 'Archivos de Suscripciones', 'setec-donaciones-aea' ),
			'parent_item_colon'     => __( 'Elemento Padre:', 'setec-donaciones-aea' ),
			'all_items'             => __( 'Todas los Suscripciones', 'setec-donaciones-aea' ),
			'add_new_item'          => __( 'Añadir Nueva Suscripcion', 'setec-donaciones-aea' ),
			'add_new'               => __( 'Añadir Nueva', 'setec-donaciones-aea' ),
			'new_item'              => __( 'Nueva Suscripcion', 'setec-donaciones-aea' ),
			'edit_item'             => __( 'Editar Suscripcion', 'setec-donaciones-aea' ),
			'update_item'           => __( 'Actualizar Suscripcion', 'setec-donaciones-aea' ),
			'view_item'             => __( 'Ver Suscripcion', 'setec-donaciones-aea' ),
			'search_items'          => __( 'Buscar Suscripcion', 'setec-donaciones-aea' ),
			'not_found'             => __( 'No encontrada', 'setec-donaciones-aea' ),
			'not_found_in_trash'    => __( 'No encontrado en la Papelera', 'setec-donaciones-aea' ),
			'featured_image'        => __( 'Imagen Destacada', 'setec-donaciones-aea' ),
			'set_featured_image'    => __( 'Elegir Imagen Destacada', 'setec-donaciones-aea' ),
			'remove_featured_image' => __( 'Quitar Imagen Destacada', 'setec-donaciones-aea' ),
			'use_featured_image'    => __( 'Usar como Imagen Destacada', 'setec-donaciones-aea' ),
			'insert_into_item'      => __( 'Insertar este elemento', 'setec-donaciones-aea' ),
			'uploaded_to_this_item' => __( 'Cargado a este elemento', 'setec-donaciones-aea' ),
			'items_list'            => __( 'Lista de Suscripciones', 'setec-donaciones-aea' ),
			'items_list_navigation' => __( 'Lista de Suscripciones', 'setec-donaciones-aea' ),
			'filter_items_list'     => __( 'Filtrar', 'setec-donaciones-aea' ),
		);
		$args = array(
			'label'                 => __( 'Listado suscripciones', 'setec-donaciones-aea' ),
			'description'           => __( 'Registra las suscripciones', 'setec-donaciones-aea' ),
			'labels'                => $labels,
			'supports'              => array( 'title' ),
			'taxonomies'            => array(),
			'hierarchical'          => false,
			'public'                => true,
			'show_ui'               => true,
			'show_in_menu'          => false,
			'menu_position'         => 100,
			'menu_icon'             => 'dashicons-calendar-alt',
			'show_in_admin_bar'     => false,
			'show_in_nav_menus'     => true,
			'can_export'            => true,
			'has_archive'           => true,		
			'exclude_from_search'   => true,
			'publicly_queryable'    => true,
			'capabilities'       => $capabilities,
		);
		register_post_type( 'aea_suscripciones', $args );

    }


    

    public function add_custom_post_fields()
	{

		if( function_exists('acf_add_local_field_group') ):

			acf_add_local_field_group(array (
				'key' => 'group_59d5bf376dbbe',
				'title' => 'campos_aea_donantes',
				'fields' => array (
					array (
						'key' => 'field_59d5bf5964482',
						'label' => 'Nombres',
						'name' => 'aea_donantes_nombres',
						'type' => 'text',
						'instructions' => 'El nombre del donante',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_59efbcdca43dc',
						'label' => 'Apellidos',
						'name' => 'aea_donantes_apellidos',
						'type' => 'text',
						'instructions' => 'El apellido del donante',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_59d5bf834f513',
						'label' => 'Email',
						'name' => 'aea_donantes_email',
						'type' => 'email',
						'instructions' => 'El email del donante',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
					),
					array (
						'key' => 'field_59d5bfe321b80',
						'label' => 'Teléfono',
						'name' => 'aea_donantes_telefono',
						'type' => 'text',
						'instructions' => 'El Teléfono del donante',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_59d5bfa7c45fd',
						'label' => 'Ciudad',
						'name' => 'aea_donantes_ciudad',
						'type' => 'text',
						'instructions' => 'La Ciudad del donante',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_5a02be3571084',
						'label' => 'Payu Customer ID',
						'name' => 'aea_donantes_payu_customerid',
						'type' => 'text',
						'instructions' => 'customer id en payulatam',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_59d5bffe0404b',
						'label' => 'Aceptación Politicas',
						'name' => 'aea_donantes_aceptacion_politicas',
						'type' => 'true_false',
						'instructions' => 'Aceptación Politicas del donante',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'message' => '',
						'default_value' => 1,
						'ui' => 0,
						'ui_on_text' => '',
						'ui_off_text' => '',
					),
				),
				'location' => array (
					array (
						array (
							'param' => 'post_type',
							'operator' => '==',
							'value' => 'aea_donantes',
						),
					),
				),
				'menu_order' => 0,
				'position' => 'normal',
				'style' => 'default',
				'label_placement' => 'top',
				'instruction_placement' => 'label',
				'hide_on_screen' => '',
				'active' => 1,
				'description' => '',
			));

			acf_add_local_field_group(array (
				'key' => 'group_5a02d4e9dc628',
				'title' => 'campos_aea_planes',
				'fields' => array (
					array (
						'key' => 'field_5a02d4f1a1cba',
						'label' => 'Plan Code',
						'name' => 'setec_donaciones_aea_plan_code',
						'type' => 'text',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_5a02d5332d528',
						'label' => 'Plan Interval',
						'name' => 'setec_donaciones_aea_plan_interval',
						'type' => 'text',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_5a02d554c9b33',
						'label' => 'Plan Value',
						'name' => 'setec_donaciones_aea_plan_value',
						'type' => 'text',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_5a02d5c9a1e6b',
						'label' => 'Plan Moneda',
						'name' => 'setec_donaciones_aea_plan_moneda',
						'type' => 'text',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_5a02dabb9853f',
						'label' => 'Plan Payu ID',
						'name' => 'aea_donantes_payu_planid',
						'type' => 'text',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
				),
				'location' => array (
					array (
						array (
							'param' => 'post_type',
							'operator' => '==',
							'value' => 'aea_planes',
						),
					),
				),
				'menu_order' => 0,
				'position' => 'normal',
				'style' => 'default',
				'label_placement' => 'top',
				'instruction_placement' => 'label',
				'hide_on_screen' => '',
				'active' => 1,
				'description' => '',
			));

			acf_add_local_field_group(array (
				'key' => 'group_5a0300c7e7a4b',
				'title' => 'campos_aea_suscripciones',
				'fields' => array (
					array (
						'key' => 'field_5a0300d07859b',
						'label' => 'Suscripcion ID',
						'name' => 'aea_donantes_payu_suscripcion_id',
						'type' => 'text',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_5a030119b0cb8',
						'label' => 'Plan code',
						'name' => 'aea_donantes_payu_suscripcion_plan_code',
						'type' => 'text',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_5a030125b0cb9',
						'label' => 'Customer ID',
						'name' => 'aea_donantes_payu_suscripcion_customer',
						'type' => 'text',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_5a030130b0cba',
						'label' => 'Token Card',
						'name' => 'aea_donantes_payu_suscripcion_token',
						'type' => 'text',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
				),
				'location' => array (
					array (
						array (
							'param' => 'post_type',
							'operator' => '==',
							'value' => 'aea_suscripciones',
						),
					),
				),
				'menu_order' => 0,
				'position' => 'normal',
				'style' => 'default',
				'label_placement' => 'top',
				'instruction_placement' => 'label',
				'hide_on_screen' => '',
				'active' => 1,
				'description' => '',
			));

			acf_add_local_field_group(array (
				'key' => 'group_5a02eb42cd3a1',
				'title' => 'campos_aea_tarjetas',
				'fields' => array (
					array (
						'key' => 'field_5a02eb6bca297',
						'label' => 'Nombre Pagador',
						'name' => 'aea_donantes_payu_tarjeta_nombre_pagador',
						'type' => 'text',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_5a02eb85a55c9',
						'label' => 'Metodo',
						'name' => 'aea_donantes_payu_tarjeta_metodo',
						'type' => 'text',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_5a02eb93d4568',
						'label' => 'Número',
						'name' => 'aea_donantes_payu_tarjeta_numero',
						'type' => 'text',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_5a02eba9475ec',
						'label' => 'Expiracion',
						'name' => 'aea_donantes_payu_tarjeta_expiracion',
						'type' => 'text',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_5a02eb4abbf28',
						'label' => 'tarjeta Idenificacion',
						'name' => 'aea_donantes_payu_tarjeta_identificacion',
						'type' => 'text',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
					array (
						'key' => 'field_5a02ebbe737cd',
						'label' => 'tarjeta Token',
						'name' => 'aea_donantes_payu_tarjeta_token',
						'type' => 'text',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array (
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
					),
				),
				'location' => array (
					array (
						array (
							'param' => 'post_type',
							'operator' => '==',
							'value' => 'aea_tarjetas',
						),
					),
				),
				'menu_order' => 0,
				'position' => 'normal',
				'style' => 'default',
				'label_placement' => 'top',
				'instruction_placement' => 'label',
				'hide_on_screen' => '',
				'active' => 1,
				'description' => '',
			));

			endif;


	}

	public function setec_exportar_donantes()
	{
		if(isset($_REQUEST['action_download_csv_donantes'])):

			remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
			remove_action( 'admin_print_styles', 'print_emoji_styles' );

			$args=array(
				'post_type' => 'aea_donantes',
				'orderby' => 'date',
				'order' => 'ASC',
				'cache_results' => false,
				'no_found_rows' => true,
				'update_post_term_cache' => false,
				'update_post_meta_cache' => false,
				'posts_per_page' => -1,
			);

			//filtro para fechas si la envia
			if($_REQUEST['fecha']!==''):



				$ayer=strtotime($_REQUEST['fecha']);
				$hoy=strtotime(date('Y-m-d'));

				$args['date_query']=array(
					array(
						'after' => array(
							'year'  => date("Y",$ayer),
							'month' => date("m",$ayer),
							'day'   => date("d",$ayer),
						),
						'before'     => array(
							'year'  => date("Y",$hoy),
							'month' => date("m",$hoy),
							'day'   => date("d",$hoy),
						),
						'inclusive' => true,
					),
				);

				// print_r($args['date_query']);
				// exit;
			endif;
			ob_start();
			$writer = new sfCsvWriter();
	        $writer->setCharset('UTF-8');
	        
	        header('Content-Type: application/msexcel;charset=ISO-8859-1');
	        header('Content-Disposition: attachment;filename=donantes_aea-'.date("Y-m-d-H:m:s").'.csv');
	        
	        $header=array('nombres','apellidos','telefono', 'email', 'ciudad', 'fecha_registro');
	        
	        echo $writer->write($header);

	        $query = new WP_Query( $args);
	        
	        if ( $query->have_posts() ):
	 			while ( $query->have_posts() ) : $query->the_post();
	 				$value = array(	 					 
	 					"nombres" => get_field('aea_donantes_nombres', $query->ID),
	 					"apellidos" => get_field('aea_donantes_apellidos', $query->ID),
	 					"telefono" => get_field('aea_donantes_telefono', $query->ID),
	 					"email" => get_field('aea_donantes_email', $query->ID),
	 					"ciudad" => get_field('aea_donantes_ciudad', $query->ID),
	 					"fecha_registro" => get_the_date());
	 				echo "\n".$writer->write($value);
	 			endwhile;
	 		endif;

	 		ob_end_flush();


		endif;


		
	}

}
