<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       setectecnologia.com
 * @since      1.0.0
 *
 * @package    Setec_Donaciones_Aea
 * @subpackage Setec_Donaciones_Aea/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Setec_Donaciones_Aea
 * @subpackage Setec_Donaciones_Aea/public
 * @author     Jefferson Quintero <quinterpriest@gmail.com>
 */

require_once dirname(__FILE__) . '/../libraries/PayU.php';   // Put class TestClass here


PayU::$apiKey = get_option('setec_donaciones_aea_payu_apikey');//Ingrese aquí su propio apiKey.
PayU::$apiLogin = get_option('setec_donaciones_aea_payu_apilogin'); //Ingrese aquí su propio apiLogin.
PayU::$merchantId =get_option('setec_donaciones_aea_payu_merchantid'); //Ingrese aquí su Id de Comercio.
PayU::$language = SupportedLanguages::ES; //Seleccione el idioma.
PayU::$isTest = true; //Dejarlo True cuando sean pruebas.

if(PayU::$isTest){
	Environment::setPaymentsCustomUrl("https://sandbox.api.payulatam.com/payments-api/4.0/service.cgi");
	// URL de Consultas
	Environment::setReportsCustomUrl("https://sandbox.api.payulatam.com/reports-api/4.0/service.cgi");
	// URL de Suscripciones para Pagos Recurrentes
	Environment::setSubscriptionsCustomUrl("https://sandbox.api.payulatam.com/payments-api/rest/v4.3/");
}
else{

	Environment::setPaymentsCustomUrl("https://api.payulatam.com/payments-api/4.0/service.cgi");
	// URL de Consultas
	Environment::setReportsCustomUrl("https://api.payulatam.com/reports-api/4.0/service.cgi");
	// URL de Suscripciones para Pagos Recurrentes
	Environment::setSubscriptionsCustomUrl("https://api.payulatam.com/payments-api/rest/v4.3/");
}


class Setec_Donaciones_Aea_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Setec_Donaciones_Aea_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Setec_Donaciones_Aea_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name."public_css", plugin_dir_url( __FILE__ ) . 'css/setec-donaciones-aea-public.css', array(), $this->version, 'all' );

		wp_enqueue_style( $this->plugin_name."_jquery_ui", '//code.jquery.com/ui/1.12.1/themes/base/jquery-ui.css', array(), $this->version, 'all' );

		wp_enqueue_style( $this->plugin_name."_prettify", plugin_dir_url( __FILE__ ) . 'css/prettify.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Setec_Donaciones_Aea_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Setec_Donaciones_Aea_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */


  wp_enqueue_script( $this->plugin_name."_jquery_ui", 'https://code.jquery.com/ui/1.12.1/jquery-ui.js', array( 'jquery' ), $this->version, true );

 wp_enqueue_script( $this->plugin_name."_bootstrap", 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/js/bootstrap.min.js', array( 'jquery' ), $this->version, true );

		wp_enqueue_script( $this->plugin_name."_validate", plugin_dir_url( __FILE__ ) . 'js/jquery.validate.min.js', array( 'jquery' ), $this->version, true );

		wp_enqueue_script( $this->plugin_name."_validate_messages", plugin_dir_url( __FILE__ ) . 'js/localization/messages_es.min.js', array( 'jquery' ), $this->version, true );

		wp_enqueue_script( $this->plugin_name."_prettify", plugin_dir_url( __FILE__ ) . 'js/prettify.js', array( 'jquery' ), $this->version, true );

		wp_enqueue_script( $this->plugin_name."_bootstrap_wizard", plugin_dir_url( __FILE__ ) . 'js/jquery.bootstrap.wizard.min.js', array( 'jquery' ), $this->version, true );

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/setec-donaciones-aea-public.js', array( 'jquery' ), $this->version, true );		

		wp_localize_script( $this->plugin_name, 'setec_add_donante', array(

        'ajax_url' => admin_url( 'admin-ajax.php' )

    ));

	}

	public function registrar_functions_ajax()
    {
        add_action( 'wp_ajax_nopriv_setec_add_donante', array( $this,'setec_add_donante') );

        add_action( 'wp_ajax_setec_add_donante', array( $this,'setec_add_donante') );
    }

    function setec_add_donante(){
	    //header('Access-Control-Allow-Origin: *');
	    $respuesta = array ('success' => true, 'msg' => '');
	    $mensaje="Gracias por tu interés, un asesor te contactará para contarte todo lo que hace Ayuda en Acción y porque tu aporte puede cambiar la vida de muchos niños en Colombia.";
	    $tipo='alert-success';

	    $nombres="";
	    if(isset($_REQUEST['nombres'])){
	    	$nombres = $_REQUEST['nombres'];
	    }
	    $apellidos = "";
	    if(isset($_REQUEST['apellidos'])){
	    	$apellidos = $_REQUEST['apellidos'];
	    }
	    $email = "";
	    if(isset($_REQUEST['email'])){
	    	$email = $_REQUEST['email'];
	    }
	    $telefono = "";
	    if(isset($_REQUEST['telefono'])){
	    	$telefono = $_REQUEST['telefono'];
	    }
	    $ciudad = "";
	    if(isset($_REQUEST['ciudad'])){
	    	$ciudad = $_REQUEST['ciudad'];
	    }
	    $aceptacion = "";
	    if(isset($_REQUEST['aceptacion'])){
	    	$aceptacion = $_REQUEST['aceptacion'];
	    }

	    $payu=false;
	    if(isset($_REQUEST['setec_payulatam'])){
	    	$payu=true;
	    }

	    $first=false;
	    if(isset($_REQUEST['setec_payulatam_first']) && $_REQUEST['setec_payulatam_first']=='1'){
	    	$first=true;
	    }

	    $customer=true;
	    $customer_id="";
	    if(isset($_REQUEST['setec_payu_customer_id']) && $_REQUEST['setec_payu_customer_id']!=''){
	    	$customer=false;
	    	$customer_id=$_REQUEST['setec_payu_customer_id'];
	    }

	    $plan=true;
	    if(isset($_REQUEST['setec_payu_plan_id']) && $_REQUEST['setec_payu_plan_id']!=''){
	    	$plan=false;
	    }

	    $interval = "";
	    if(isset($_REQUEST['setec_payulatam_plan_interval'])){
	    	$interval = $_REQUEST['setec_payulatam_plan_interval'];
	    }

	    $value = "";
	    if(isset($_REQUEST['setec_payulatam_plan_amount'])){
	    	$value = $_REQUEST['setec_payulatam_plan_amount'];
	    }



	    $tarjeta=true;
	    if(isset($_REQUEST['setec_payu_tarjeta_id']) && $_REQUEST['setec_payu_tarjeta_id']!=''){
	    	$tarjeta=false;
	    }

	    $pagador = "";
	    if(isset($_REQUEST['setec_payulatam_pagador'])){
	    	$pagador = $_REQUEST['setec_payulatam_pagador'];
	    }

	    $metodo = "";
	    if(isset($_REQUEST['setec_payulatam_metodo'])){
	    	$metodo = $_REQUEST['setec_payulatam_metodo'];
	    }

	    $numberCard = "";
	    if(isset($_REQUEST['setec_payulatam_numero_tarjeta'])){
	    	$numberCard = $_REQUEST['setec_payulatam_numero_tarjeta'];
	    }

	    $expiration = "";
	    if(isset($_REQUEST['setec_payulatam_expiracion'])){
	    	$expiration = $_REQUEST['setec_payulatam_expiracion'];
	    }

	    $identificacion = "";
	    if(isset($_REQUEST['setec_payulatam_identificacion'])){
	    	$identificacion = $_REQUEST['setec_payulatam_identificacion'];
	    }

	    $suscripcion=false;
	    

	    $plan_code="";
	    if(isset($_REQUEST['setec_plan_code'])){
	    	$plan_code = $_REQUEST['setec_plan_code'];
	    }

	    $token="";
	    if(isset($_REQUEST['setec_payu_tarjeta_id'])){
	    	$token = $_REQUEST['setec_payu_tarjeta_id'];
	    }


	    
	    

	    

	    if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) { 

	    	$donante_id= "";

	    	if($first){

	    		$donante = array(
				 'post_title' => $nombres,
				 'post_type' => 'aea_donantes',
				 'post_content'=>"Donante",
				 'post_status' => 'publish',
				 'post_author' => 1
				);
				// Insert the post into the database
				$donante_id = wp_insert_post( $donante );
				//crear el pago

				if($nombres!=null && $nombres!=''){
					update_field("field_59d5bf5964482", $nombres, $donante_id);
				}
				if($apellidos!=null && $apellidos!=''){
					update_field("field_59efbcdca43dc", $apellidos, $donante_id);
				}
				if($email!=null && $email!=''){
					update_field("field_59d5bf834f513", $email, $donante_id);
				}
				if($telefono!=null && $telefono!=''){
					update_field("field_59d5bfe321b80", $telefono, $donante_id);
				}
				if($ciudad!=null && $ciudad!=''){
					update_field("field_59d5bfa7c45fd", $ciudad, $donante_id);
				}
				
				update_field("field_59d5bffe0404b", 1, $donante_id);
	    	}		
	    			

			if($payu){

				if($plan){
					$payuPlan=$this->gestionar_plan($interval, $value);

		  			if($payuPlan['success']){
		  				update_field("field_5a02dabb9853f", $payuPlan['response']->id, $payuPlan['key']);
		  				$respuesta['payu']['plan']=$payuPlan;
		  				$respuesta['payu']['plan']['code']=get_field( "field_5a02d4f1a1cba", $payuPlan['key']);
		  			}
		  		}

		  		if($customer){
		  			$payuCliente=$this->gestionar_cliente($nombres, $apellidos, $email, $donante_id);
			  		if($payuCliente['success']){			
			  			update_field("field_5a02be3571084", $payuCliente['response']->id, $donante_id);  			
			  			$respuesta['payu']['customer']=$payuCliente;
			  		}
		  		}else{

		  			if($tarjeta){

		  				$payuTarjeta['success']=false;

		  				try{
		  			$payuTarjeta=$this->gestionar_tarjeta( $customer_id, $pagador, $metodo, $numberCard, $expiration, $identificacion);
		  				}catch (Exception $e){
		  					$respuesta['payu']['tarjeta']['success']=false;
		  					$respuesta['payu']['tarjeta']['msg']="Error: ".$e->getMessage();		  					
		  				}
			  			
				  		if($payuTarjeta['success']){			

				  			$tarjeta = array(
							 'post_title' => $metodo." ".$expiration,
							 'post_type' => 'aea_tarjetas',
							 'post_content'=>"tarjeta",
							 'post_status' => 'publish',
							 'post_author' => 1
							);
							
							// Insert the post into the database
							$tarjeta_id = wp_insert_post( $tarjeta );

							update_field("field_5a02eb6bca297", $pagador, $tarjeta_id);
							update_field("field_5a02eb85a55c9", $metodo, $tarjeta_id);
							update_field("field_5a02eb93d4568", $numberCard, $tarjeta_id);
							update_field("field_5a02eba9475ec", $expiration, $tarjeta_id);
							update_field("field_5a02eb4abbf28", $identificacion, $tarjeta_id);
				  			update_field("field_5a02ebbe737cd", $payuTarjeta['response']->token, $tarjeta_id);

				  			$respuesta['payu']['tarjeta']=$payuTarjeta;
				  			$respuesta['payu']['tarjeta']['key']=$tarjeta_id;
				  		}


			  		}
			  		else{

			  				$suscripcion=true;

			  		}

		  		}


		  		if($suscripcion){



			  				try{		  					
			  					
			  					$payuSuscripcion=$this->gestionar_suscripcion( $plan_code, $customer_id, $token);


			  					if($payuSuscripcion['success']){	



						  			$suscripcion = array(
									 'post_title' => "suscripcion ".$payuSuscripcion['response']->id,
									 'post_type' => 'aea_suscripciones',
									 'post_content'=>"suscripcion",
									 'post_status' => 'publish',
									 'post_author' => 1
									);
									
									// Insert the post into the database
									$suscripcion_id = wp_insert_post( $suscripcion );

									update_field("field_5a0300d07859b", $payuSuscripcion['response']->id, $suscripcion_id);
									update_field("field_5a030119b0cb8", $plan_code, $suscripcion_id);
									update_field("field_5a030125b0cb9", $customer_id, $suscripcion_id);
									update_field("field_5a030130b0cba", $token, $suscripcion_id);

						  			$respuesta['payu']['suscripcion']=$payuSuscripcion;
						  			$respuesta['payu']['suscripcion']['key']=$suscripcion_id;
						  		}
			  				}catch (Exception $e){			  					
			  					$respuesta['payu']['suscripcion']['success']=false;
			  					$respuesta['payu']['suscripcion']['msg']="Error: ".$e->getMessage();
			  					
			  				}

			  			}	

		  		

		  		
			}
	        
	    }else{
	    	$respuesta['success']=false;
	    	$mensaje="Ocurrio un Error";
	    	$tipo='alert-danger';
	    }

	    $respuesta['msg']='<div class="alert alert-dismissable '.$tipo.'">';
  		$respuesta['msg'].='<a href="#" class="close" data-dismiss="alert" aria-label="close">&times;</a>';
  		$respuesta['msg'].='<strong>'.$mensaje.'</strong></div>';

	    header('Content-type: application/json; charset=utf-8');
	    echo json_encode($respuesta);

	    wp_die();
	}

	public function setec_donaciones_aea_shortcode() 
	{
		include_once 'partials/setec-donaciones-aea-shortcode-display.php';
	}

	public function registrar_shortcodes(){
		add_shortcode( 'setec_donaciones_aea', array( $this, 'setec_donaciones_aea_shortcode') );
	}

	public function gestionar_api_payu($class, $method, $params, $key = null){

		$respuesta = array ('success' => false, 'response' => 'Error');	
		$response = call_user_func($class.'::'.$method, $params);

		if($response){

			$respuesta = array ('success' => true, 'response' => $response, 'key' => $key);	
		}
		return $respuesta;
	}


	public function gestionar_cliente($nombres, $apellidos, $email, $donante_id){

		$parameters = array(
			// Ingresa aquí el nombre del cliente
			PayUParameters::CUSTOMER_NAME => $nombres." ".$apellidos,
			// Ingresa aquí el correo del cliente
			PayUParameters::CUSTOMER_EMAIL => $email
		);
		
		return $this->gestionar_api_payu('PayUCustomers','create', $parameters, $donante_id);
	}	

	public function gestionar_plan($interval, $value){		

		$time=time();

		$parameters = array(
			// Ingresa aquí la descripción del plan
			PayUParameters::PLAN_DESCRIPTION => "Plan Mensual ".$time,
			// Ingresa aquí el código de identificación para el plan
			PayUParameters::PLAN_CODE => "plan-mensual-".$time,
			// Ingresa aquí el intervalo del plan
			//DAY||WEEK||MONTH||YEAR
			PayUParameters::PLAN_INTERVAL => $interval,
			// Ingresa aquí la cantidad de intervalos
			PayUParameters::PLAN_INTERVAL_COUNT => "1",
			// Ingresa aquí la moneda para el plan
			PayUParameters::PLAN_CURRENCY => "COP",
			// Ingresa aquí el valor del plan
			PayUParameters::PLAN_VALUE => $value,
			PayUParameters::ACCOUNT_ID => get_option('setec_donaciones_aea_payu_accountid'),
			// Ingresa aquí el intervalo de reintentos
			PayUParameters::PLAN_ATTEMPTS_DELAY => "1",
			// Ingresa aquí la cantidad de cobros que componen el plan
			PayUParameters::PLAN_MAX_PAYMENTS => "12",
			// Ingresa aquí la cantidad total de reintentos para cada pago rechazado de la suscripción
			PayUParameters::PLAN_MAX_PAYMENT_ATTEMPTS => "3",
			// Ingresa aquí la cantidad máxima de pagos pendientes que puede tener una suscripción antes de ser cancelada.
			PayUParameters::PLAN_MAX_PENDING_PAYMENTS => "1",
			// Ingresa aquí la cantidad de días de prueba de la suscripción.
			PayUParameters::TRIAL_DAYS => "30",
		);


		$plan = array(
		 'post_title' => "Plan Mensual ".$time,
		 'post_type' => 'aea_planes',
		 'post_content'=>"Planes",
		 'post_status' => 'publish',
		 'post_author' => 1
		);
		
		// Insert the post into the database
		$plan_id = wp_insert_post( $plan );

		update_field("field_5a02d4f1a1cba", "plan-mensual-".$time, $plan_id);
		update_field("field_5a02d5332d528", $interval, $plan_id);
		update_field("field_5a02d554c9b33", $value, $plan_id);
		update_field("field_5a02d5c9a1e6b", "COP", $plan_id);	

		return $this->gestionar_api_payu('PayUSubscriptionPlans','create', $parameters, $plan_id);
	}


	public function gestionar_tarjeta($idCliente, $nombresPagador, $method,  $numberCard, $expiration,  $document){

		$parameters = array(
			// Ingresa aquí el identificador del cliente,
			PayUParameters::CUSTOMER_ID => $idCliente,
			// Ingresa aquí el nombre del cliente
			PayUParameters::PAYER_NAME => $nombresPagador,
			// Ingresa aquí el número de la tarjeta de crédito
			PayUParameters::CREDIT_CARD_NUMBER => $numberCard,
			// Ingresa aquí la fecha de expiración de la tarjeta de crédito en formato AAAA/MM
			PayUParameters::CREDIT_CARD_EXPIRATION_DATE => $expiration,
			// Ingresa aquí el nombre de la franquicia de la tarjeta de crédito
			PayUParameters::PAYMENT_METHOD => $method,
		        // Ingresa aquí el documento de identificación asociado a la tarjeta
			PayUParameters::CREDIT_CARD_DOCUMENT => $document
		);
		return $this->gestionar_api_payu('PayUCreditCards','create', $parameters);
	}	

	public function gestionar_suscripcion($planCode, $idCliente, $tokenId){

		$parameters = array(
			// Ingresa aquí el código del plan a suscribirse.
			PayUParameters::PLAN_CODE => $planCode,
			// Ingresa aquí el identificador del pagador.
			PayUParameters::CUSTOMER_ID => $idCliente,
			// Ingresa aquí el identificador del token de la tarjeta.
			PayUParameters::TOKEN_ID => $tokenId,
			// Ingresa aquí la cantidad de días de prueba de la suscripción.
			PayUParameters::TRIAL_DAYS => "10",
			// Ingresa aquí el número de cuotas a pagar.
			PayUParameters::INSTALLMENTS_NUMBER => "1",
		);

		return $this->gestionar_api_payu('PayUSubscriptions','createSubscription', $parameters);
	}	

}